@@ -1,6 +1,6 @@
 /*
  *   ksendfax - a interface to fax-packages
- *   Copyright (C) 1998  Juergen Vigna
+ *   Copyright (C) 1998-2000  Jrgen Vigna
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,28 +21,33 @@
 #ifndef MyProcess_included
 #define MyProcess_included
 
+#include <qstringlist.h>
+
 #include <kprocess.h>
 
 class MyProcess : public KShellProcess
 {
-    Q_OBJECT
+	Q_OBJECT
 
 public:
-    MyProcess(const char *shellname=NULL,bool init=true);
-    void setLocalData(const char *data);
-    const char *localData();
-    int
-        row;
-    QString
-        stderr_str,
-        stdout_str;
+	MyProcess(const char *shellname=NULL, bool init=true);
+	void setLocalData(const QStringList &);
+	const QStringList & localData() const;
+	
+	int row;
+	QString stderr_str;
+	QString stdout_str;
+
+protected:
+	int childOutput(int fdno);
+	int childError(int fdno);
 
 protected slots:
-    void ReadStderr(KProcess *, char *buffer, int buflen);
-    void ReadStdout(KProcess *, char *buffer, int buflen);
+	void ReadStderr(KProcess *, char *buffer, int buflen);
+	void ReadStdout(KProcess *, char *buffer, int buflen);
 
 private:
-    QString
-        descStr;
+	QStringList localData_;
+
 };
 #endif // MyProcess_included
